@@ -15,17 +15,17 @@ typedef struct request {
 	char username[MAXBUFSIZ];	
 	char password[MAXBUFSIZ];
 	int port;
-	int clength;			/* Content-length	*/
+	long long clength;		/* Content-length	*/
 	unsigned char proto;		/* Protocol		*/
 } request;
 
 typedef struct thread_data {
 	struct sockaddr_in sin;
 	char getstr[GETREQSIZ];
-	long soffset;		/* Start offset		*/
-	long foffset;		/* Finish offset	*/
-	long offset;		/* Current Offset	*/
-	long clength;		/* Content Length	*/
+	long long soffset;		/* Start offset		*/
+	long long foffset;		/* Finish offset	*/
+	long long offset;		/* Current Offset	*/
+	long long clength;		/* Content Length	*/
 	int fd;
 	pthread_t tid;		/* Thread ID		*/
 	unsigned char status;	/* thread exit status	*/
