@@ -22,8 +22,8 @@ enum {
 };
 
 
-#define	PROGVERSION  "EnderUNIX Aget v0.4"
+#define	PROGVERSION  "EnderUNIX Aget v0.4.1"
 #define	HEADREQ  "HEAD %s HTTP/1.1\r\nHost: %s\r\nUser-Agent: %s\r\n\r\n"
-#define	GETREQ  "GET %s HTTP/1.1\r\nHost: %s\r\nUser-Agent: %s\r\nRange: bytes=%ld-\r\nConnection: close\r\n\r\n"
+#define	GETREQ  "GET %s HTTP/1.1\r\nHost: %s\r\nUser-Agent: %s\r\nRange: bytes=%lld-\r\nConnection: close\r\n\r\n"
 
 #endif
