@@ -15,7 +15,7 @@
 
 #define	LOGSIZ	1024
 
-int calc_offset(int, int, int);
+int calc_offset(long long, int, int);
 int numofthreads(int);
 void parse_url(char *, struct request *);
 void usage();
